==> run_markdown-1.1.65579.tar.gz: run_markdown-1.1.65579/run_markdown/text_comparator.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
import operator
from typing import ClassVar

from run_markdown.base_comparator import BaseComparator
from run_markdown.comparison_buffer import ComparisonBuffer
from run_markdown.comparison_line import TextComparisonLine
from run_markdown.utils import compare_string_with_pattern


class TextComparator(BaseComparator):
    chars_to_ignore: ClassVar[str] = '\r'
    def compare(self, value: str) -> ComparisonBuffer:
        expected = self.expected
        actual = value
        for char in self.chars_to_ignore:
            # expected = expected.replace(char, '')
            # actual = actual.replace(char, '')
            pass
        result = ComparisonBuffer()
        expected_lines = expected.splitlines()
        actual_lines = actual.splitlines()
        for expected_line, actual_line in zip(expected_lines, actual_lines):
            if '...' in expected_line:
                comparator = compare_string_with_pattern
                error_text = 'Value mismatch'
            else:
                comparator = operator.eq
                error_text = 'Value non equal'
            exception = None if comparator(expected_line, actual_line) else ValueError(error_text)
            result.append(TextComparisonLine(expected_line, actual_line, exception))
        for i in range(len(actual_lines), len(expected_lines)):
            result.append(TextComparisonLine(expected_lines[i], '', ValueError(f"Missing line")))
        for i in range(len(expected_lines), len(actual_lines)):
            result.append(TextComparisonLine('', actual_lines[i], ValueError(f"Extra line")))
        return result

==> run_markdown-1.2.65615.tar.gz: run_markdown-1.2.65615/run_markdown/text_comparator.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
import operator
from typing import ClassVar

from run_markdown.base_comparator import BaseComparator
from run_markdown.comparison_buffer import ComparisonBuffer
from run_markdown.comparison_line import TextComparisonLine
from run_markdown.utils import compare_string_with_pattern


class TextComparator(BaseComparator):
    chars_to_ignore: ClassVar[str] = '\r'

    def compare(self, value: str) -> ComparisonBuffer:
        expected = self.expected
        actual = value
        for char in self.chars_to_ignore:
            expected = expected.replace(char, '')
            actual = actual.replace(char, '')
        result = ComparisonBuffer()
        expected_lines = expected.splitlines()
        actual_lines = actual.splitlines()
        for expected_line, actual_line in zip(expected_lines, actual_lines):
            if '...' in expected_line:
                comparator = compare_string_with_pattern
                error_text = 'Value mismatch'
            else:
                comparator = operator.eq
                error_text = 'Value non equal'
            exception = None if comparator(expected_line, actual_line) else ValueError(error_text)
            result.append(TextComparisonLine(expected_line, actual_line, exception))
        for i in range(len(actual_lines), len(expected_lines)):
            result.append(TextComparisonLine(expected_lines[i], '', ValueError(f"Missing line")))
        for i in range(len(expected_lines), len(actual_lines)):
            result.append(TextComparisonLine('', actual_lines[i], ValueError(f"Extra line")))
        return result
